@@ -172,7 +172,7 @@ ergm.AME<-function(model,var1,var2=NULL,inter=NULL,at.2=NULL, return.dydx=FALSE,
            AME<-matrix(c(AME,AME.se,AME.z,P.AME),nrow=1,ncol=4)
             colnames(AME)<-c("AME","Delta SE","Z","P")
             rownames(AME)<-inter
-            message("NOTE: Nodematch is an interaction, but it is not a product term (e.g., inter!=var1*var2). Z statistics in summary(ergm) are unbiased.")
+            message("NOTE: Nodematch is an interaction, but it is not a product of the main effects (e.g., inter!=var1*var2). Returning the simple AME for the interaction. Consider respecifying ERGM using nodefactor for main effects or absdiff instead of nodematch to measure homophily.")
             marginal.matrix<-signif(marginal.matrix,digits=5)
             AME<-signif(AME,digits=5)
             AME<-list(AME,marginal.matrix)
